summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/oscarclientstream.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/oscarclientstream.h')
-rw-r--r--kopete/protocols/oscar/liboscar/oscarclientstream.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/protocols/oscar/liboscar/oscarclientstream.h b/kopete/protocols/oscar/liboscar/oscarclientstream.h
index f8b4d2b6..307c0616 100644
--- a/kopete/protocols/oscar/liboscar/oscarclientstream.h
+++ b/kopete/protocols/oscar/liboscar/oscarclientstream.h
@@ -73,19 +73,19 @@ public:
BindConflict // resource in-use
};
- ClientStream(Connector *conn, QObject *parent=0);
+ ClientStream(Connector *conn, TQObject *parent=0);
~ClientStream();
- void connectToServer(const QString& server, bool auth=true);
+ void connectToServer(const TQString& server, bool auth=true);
void accept(); // server
bool isActive() const;
bool isAuthenticated() const;
// login params
- void setUsername(const QString &s);
- void setPassword(const QString &s);
+ void setUsername(const TQString &s);
+ void setPassword(const TQString &s);
- void setLocalAddr(const QHostAddress &addr, Q_UINT16 port);
+ void setLocalAddr(const TQHostAddress &addr, Q_UINT16 port);
void close();
@@ -110,10 +110,10 @@ public:
void write( Transfer* request );
int errorCondition() const;
- QString errorText() const;
+ TQString errorText() const;
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
/*# void writeDirect(const QString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals:
@@ -130,7 +130,7 @@ private slots:
/**
* collects wire ready outgoing data from the core protocol and sends
*/
- void cp_outgoingData( const QByteArray& );
+ void cp_outgoingData( const TQByteArray& );
/**
* collects parsed incoming data as a transfer from the core protocol and queues
*/
@@ -110,10 +110,10 @@ public:
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
-/*# void writeDirect(const QString &s); // must be for debug testing*/
+/*# void writeDirect(const TQString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals: